.. Sardana documentation master file

Welcome to Sardana's |version| documentation!
=============================================

.. figure:: /_static/sardana_screenshot.png
    :width: 500

Sardana is the control program initially developed at ALBA_. Our mission statement:

    `Produce a modular, high performance, robust, and generic user environment
    for control applications in large and small installations. Make Sardana
    the generic user environment distributed in the TANGO project and the
    standard basis of collaborations in control.`
    

An :ref:`sardana-overview` guide will help you getting started with the 
basic sardana concepts. The :ref:`sardana-faq` will answer many of your questions.

For sampling, see the :ref:`screenshots` and :ref:`devel-examples` chapters.

.. toctree::
    :hidden:

    contents
    glossary
    
:Last Update: |today|


.. _ALBA: http://www.cells.es/
.. _ANKA: http://http://ankaweb.fzk.de/
.. _ELETTRA: http://http://www.elettra.trieste.it/
.. _ESRF: http://www.esrf.eu/
.. _FRMII: http://www.frm2.tum.de/en/index.html
.. _HASYLAB: http://hasylab.desy.de/
.. _MAX-lab: http://www.maxlab.lu.se/maxlab/max4/index.html
.. _SOLEIL: http://www.synchrotron-soleil.fr/

.. _TANGO: http://www.tango-controls.org/
.. _Tango: http://www.tango-controls.org/
.. _PyTango: http://packages.python.org/PyTango/
.. _Taurus: http://packages.python.org/taurus/
.. _QTango: http://www.tango-controls.org/download/index_html#qtango3
.. _Qt: http://qt.nokia.com/products/
.. _PyQt: http://www.riverbankcomputing.co.uk/software/pyqt/
.. _PyQwt: http://pyqwt.sourceforge.net/
.. _Python: http://www.python.org/
.. _IPython: http://ipython.scipy.org/
.. _ATK: http://www.tango-controls.org/Documents/gui/atk/tango-application-toolkit
.. _Qub: http://www.blissgarden.org/projects/qub/
.. _numpy: http://numpy.scipy.org/
.. _SPEC: http://www.certif.com/
.. _EPICS: http://www.aps.anl.gov/epics/
